@@ -1,8 +1,7 @@
-import os
 import re
 import sys
 from caos._internal.utils.os import is_posix_os, is_win_os
-from caos._third_party.ansi189 import ansicon
+from caos._third_party.colorama_0_4_3 import load_colorama
 
 
 def supports_color() -> bool:
@@ -10,8 +9,8 @@ def supports_color() -> bool:
     Returns True if the running system's terminal supports color, and False
     otherwise.
     """
-    supported_platform = is_posix_os() or os.environ.get('ANSICON') or (is_win_os() and ansicon.load())
-    is_a_tty = hasattr(sys.stdout, 'isatty') and sys.stdout.isatty() # isatty is not always present
+    supported_platform = is_posix_os() or (is_win_os() and load_colorama())
+    is_a_tty = hasattr(sys.stdout, 'isatty') and sys.stdout.isatty()  # isatty is not always present
     return supported_platform and is_a_tty
 
 
